@@ -5,10 +5,8 @@ package Test::Exception;
 use Test::Builder;
 use Sub::Uplevel qw( uplevel );
 use base qw( Exporter );
-use Scalar::Util 'blessed';
-use Carp;
 
-our $VERSION = '0.27_04';
+our $VERSION = '0.28_01';
 our @EXPORT = qw(dies_ok lives_ok throws_ok lives_and);
 
 my $Tester = Test::Builder->new;
@@ -25,7 +23,7 @@ sub import {
 
 =head1 NAME
 
-Test::Exception - Test exception-based code
+Test::Exception - Test exception based code
 
 =head1 SYNOPSIS
 
@@ -70,20 +68,17 @@ Test::Exception - Test exception-based code
 
 =head1 DESCRIPTION
 
-This module provides a few convenience methods for testing exception
-based code. It is built with L<Test::Builder> and plays happily with
-L<Test::More> and friends.
+This module provides a few convenience methods for testing exception based code. It is built with 
+L<Test::Builder> and plays happily with L<Test::More> and friends.
 
-If you are not already familiar with L<Test::More> now would be the
-time to go take a look.
+If you are not already familiar with L<Test::More> now would be the time to go take a look.
 
-You can specify the test plan when you C<use Test::Exception> in the
-same way as C<use Test::More>. See L<Test::More> for details.
+You can specify the test plan when you C<use Test::Exception> in the same way as C<use Test::More>.
+See L<Test::More> for details.
 
-NOTE: Test::Exception only checks for exceptions. It will ignore other
-methods of stopping program execution - including exit(). If you have
-an exit() in evalled code Test::Exception will not catch this with any
-of its testing functions.
+NOTE: Test::Exception only checks for exceptions. It will ignore other methods of stopping 
+program execution - including exit(). If you have an exit() in evalled code Test::Exception
+will not catch this with any of its testing functions.
 
 =cut
 
@@ -98,11 +93,6 @@ sub _quiet_caller (;$) { ## no critic Prototypes
     }
 }
 
-my $DIED;
-sub _DIED {
-    $DIED = shift;
-}
-
 sub _try_as_caller {
     my $coderef = shift;
 
@@ -110,26 +100,8 @@ sub _try_as_caller {
     local *CORE::GLOBAL::caller;
     { no warnings 'redefine'; *CORE::GLOBAL::caller = \&_quiet_caller; }
 
-    local $@;
-    local $SIG{__DIE__} = $SIG{__DIE__};
-    undef $DIED;
-
-    my $failed = not defined eval {
-        $SIG{__DIE__} = \ &_DIED;
-        uplevel 3, $coderef;
-        1;
-    };
-
-    # certain uses of Class::Exception were doing odd things to $@ once
-    # I accessed it. Instead, I'll convert to the better practice of 
-    # saving the value. Should we just save the string value? This seems
-    # to work:
-	my $error = $@;
-	
-    return defined $error && length $error  ? $error       :
-           defined $DIED                    ? "Died with ... $DIED\n" :
-           $failed                          ? "Died mysteriously (no error)\n" :
-                                              '';
+    eval { uplevel 3, $coderef };
+    return $@;
 };
 
 
@@ -159,58 +131,49 @@ Tests to see that a specific exception is thrown. throws_ok() has two forms:
   throws_ok BLOCK REGEX, TEST_DESCRIPTION
   throws_ok BLOCK CLASS, TEST_DESCRIPTION
 
-In the first form the test passes if the stringified exception matches
-the give regular expression. For example:
+In the first form the test passes if the stringified exception matches the give regular expression. For example:
 
     throws_ok { read_file( 'unreadable' ) } qr/No file/, 'no file';
 
-If your perl does not support C<qr//> you can also pass a regex-like
-string, for example:
+If your perl does not support C<qr//> you can also pass a regex-like string, for example:
 
     throws_ok { read_file( 'unreadable' ) } '/No file/', 'no file';
 
-The second form of throws_ok() test passes if the exception is of the
-same class as the one supplied, or a subclass of that class. For
-example:
+The second form of throws_ok() test passes if the exception is of the same class as the one supplied, or a subclass of that class. For example:
 
     throws_ok { $foo->bar } "Error::Simple", 'simple error';
 
-Will only pass if the C<bar> method throws an Error::Simple exception,
-or a subclass of an Error::Simple exception.
+Will only pass if the C<bar> method throws an Error::Simple exception, or a subclass of an Error::Simple exception.
 
-You can get the same effect by passing an instance of the exception
-you want to look for. The following is equivalent to the previous
-example:
+You can get the same effect by passing an instance of the exception you want to look for. The following is equivalent to the previous example:
 
     my $SIMPLE = Error::Simple->new;
     throws_ok { $foo->bar } $SIMPLE, 'simple error';
 
-Should a throws_ok() test fail it produces appropriate diagnostic
-messages. For example:
+Should a throws_ok() test fail it produces appropriate diagnostic messages. For example:
 
     not ok 3 - simple error
     #     Failed test (test.t at line 48)
     # expecting: Error::Simple exception
     # found: normal exit
 
-Like all other Test::Exception functions you can avoid prototypes by
-passing a subroutine explicitly:
+Like all other Test::Exception functions you can avoid prototypes by passing a subroutine explicitly:
 
     throws_ok( sub {$foo->bar}, "Error::Simple", 'simple error' );
 
-A true value is returned if the test succeeds, false otherwise. On
-exit $@ is guaranteed to be the cause of death (if any).
+A true value is returned if the test succeeds, false otherwise. On exit $@ is guaranteed to be the cause of death (if any).
 
-A description of the exception being checked is used if no optional
-test description is passed.
+A description of the exception being checked is used if no optional test description is passed.
 
 =cut
 
 
 sub throws_ok (&$;$) {
     my ( $coderef, $expecting, $description ) = @_;
-    croak "throws_ok: must pass exception class/object or regex" 
-        unless defined $expecting;
+    unless (defined $expecting) {
+      require Carp;
+      Carp::croak( "throws_ok: must pass exception class/object or regex" ); 
+    }
     $description = _exception_as_string( "threw", $expecting )
     	unless defined $description;
     my $exception = _try_as_caller( $coderef );
@@ -244,14 +207,11 @@ Checks that a piece of code dies, rather than returning normally. For example:
     # or if you don't like prototypes
     dies_ok( sub { div( 1, 0 ) }, 'divide by zero detected' );
 
-A true value is returned if the test succeeds, false otherwise. On
-exit $@ is guaranteed to be the cause of death (if any).
+A true value is returned if the test succeeds, false otherwise. On exit $@ is guaranteed to be the cause of death (if any).
 
-Remember: This test will pass if the code dies for any reason. If you
-care about the reason it might be more sensible to write a more
-specific test using throws_ok().
+Remember: This test will pass if the code dies for any reason. If you care about the reason it might be more sensible to write a more specific test using throws_ok().
 
-The test description is optional, but recommended.
+The test description is optional, but recommended. 
 
 =cut
 
@@ -266,9 +226,7 @@ sub dies_ok (&;$) {
 
 =item B<lives_ok>
 
-Checks that a piece of code doesn't die. This allows your test script
-to continue, rather than aborting if you get an unexpected exception.
-For example:
+Checks that a piece of code doesn't die. This allows your test script to continue, rather than aborting if you get an unexpected exception. For example:
 
     sub read_file {
         my $file = shift;
@@ -284,17 +242,15 @@ For example:
     # or if you don't like prototypes
     lives_ok( sub { $file = read_file('test.txt') }, 'file read' );
 
-Should a lives_ok() test fail it produces appropriate diagnostic
-messages. For example:
+Should a lives_ok() test fail it produces appropriate diagnostic messages. For example:
 
     not ok 1 - file read
     #     Failed test (test.t at line 15)
     # died: open failed (No such file or directory)
 
-A true value is returned if the test succeeds, false otherwise. On
-exit $@ is guaranteed to be the cause of death (if any).
+A true value is returned if the test succeeds, false otherwise. On exit $@ is guaranteed to be the cause of death (if any).
 
-The test description is optional, but recommended.
+The test description is optional, but recommended. 
 
 =cut
 
@@ -326,15 +282,13 @@ Which is the same as doing
 
   is read_file('answer.txt'), "42\n", 'answer is 42';
 
-unless C<read_file('answer.txt')> dies, in which case you get the same
-kind of error as lives_ok()
+unless C<read_file('answer.txt')> dies, in which case you get the same kind of error as lives_ok()
 
   not ok 1 - answer is 42
   #     Failed test (test.t at line 15)
   # died: open failed (No such file or directory)
 
-A true value is returned if the test succeeds, false otherwise. On
-exit $@ is guaranteed to be the cause of death (if any).
+A true value is returned if the test succeeds, false otherwise. On exit $@ is guaranteed to be the cause of death (if any).
 
 The test description is optional, but recommended.
 
@@ -367,10 +321,7 @@ sub lives_and (&;$) {
 
 =head1 SKIPPING TEST::EXCEPTION TESTS
 
-Sometimes we want to use Test::Exception tests in a test suite, but
-don't want to force the user to have Test::Exception installed. One
-way to do this is to skip the tests if Test::Exception is absent. You
-can do this with code something like this:
+Sometimes we want to use Test::Exception tests in a test suite, but don't want to force the user to have Test::Exception installed. One way to do this is to skip the tests if Test::Exception is absent. You can do this with code something like this:
 
   use strict;
   use warnings;
@@ -384,20 +335,18 @@ can do this with code something like this:
   plan tests => 2;
   # ... tests that need Test::Exception ...
 
-Note that we load Test::Exception in a C<BEGIN> block ensuring that
-the subroutine prototypes are in place before the rest of the test
-script is compiled.
+Note that we load Test::Exception in a C<BEGIN> block ensuring that the subroutine prototypes are in place before the rest of the test script is compiled.
 
 
 =head1 BUGS
 
-There are some edge cases in Perl's exception handling where
-Test::Exception will miss exceptions thrown in DESTROY blocks. See the
-RT bug L<http://rt.cpan.org/Ticket/Display.html?id=24678> for details,
-along with the t/edge-cases.t in the distribution test suite.
+There are some edge cases in Perl's exception handling where Test::Exception will miss exceptions
+thrown in DESTROY blocks. See the RT bug L<http://rt.cpan.org/Ticket/Display.html?id=24678> for
+details, along with the t/edge-cases.t in the distribution test suite. These will be addressed in
+a future Test::Exception release.
 
-If you find any more bugs please let me know by e-mail, or report the
-problem with L<http://rt.cpan.org/>.
+If you find any more bugs please let me know by e-mail, or report the problem with 
+L<http://rt.cpan.org/>.
 
 
 =head1 COMMUNITY
@@ -406,46 +355,33 @@ problem with L<http://rt.cpan.org/>.
 
 =item perl-qa
 
-If you are interested in testing using Perl I recommend you visit
-L<http://qa.perl.org/> and join the excellent perl-qa mailing list.
-See L<http://lists.perl.org/showlist.cgi?name=perl-qa> for details on
-how to subscribe.
+If you are interested in testing using Perl I recommend you visit L<http://qa.perl.org/> and join the excellent perl-qa mailing list. See L<http://lists.perl.org/showlist.cgi?name=perl-qa> for details on how to subscribe.
 
 =item perlmonks
 
-You can find users of Test::Exception, including the module author, on
- L<http://www.perlmonks.org/>. Feel free to ask questions on
-Test::Exception there.
+You can find users of Test::Exception, including the module author, on  L<http://www.perlmonks.org/>. Feel free to ask questions on Test::Exception there.
 
 =item CPAN::Forum
 
-The CPAN Forum is a web forum for discussing Perl's CPAN modules.  
-The Test::Exception forum can be found at
-L<http://www.cpanforum.com/dist/Test-Exception>.
+The CPAN Forum is a web forum for discussing Perl's CPAN modules.   The Test::Exception forum can be found at L<http://www.cpanforum.com/dist/Test-Exception>.
 
 =item AnnoCPAN
 
-AnnoCPAN is a web site that allows community annotations of Perl
-module documentation. The Test::Exception annotations can be found at
-L<http://annocpan.org/~ADIE/Test-Exception/>.
+AnnoCPAN is a web site that allows community annotations of Perl module documentation. The Test::Exception annotations can be found at L<http://annocpan.org/~ADIE/Test-Exception/>.
 
 =back
 
 
 =head1 TO DO
 
-If you think this module should do something that it doesn't (or does
-something that it shouldn't) please let me know.
+If you think this module should do something that it doesn't (or does something that it shouldn't) please let me know.
 
-You can see my current to do list at
-L<http://adrianh.tadalist.com/lists/public/15421>, with an RSS feed of
-changes at L<http://adrianh.tadalist.com/lists/feed_public/15421>.
+You can see my current to do list at L<http://adrianh.tadalist.com/lists/public/15421>, with an RSS feed of changes at L<http://adrianh.tadalist.com/lists/feed_public/15421>.
 
 
 =head1 ACKNOWLEDGMENTS
 
-Thanks to chromatic and Michael G Schwern for the excellent
-Test::Builder, without which this module wouldn't be possible.
+Thanks to chromatic and Michael G Schwern for the excellent Test::Builder, without which this module wouldn't be possible.
 
 Thanks to 
 Adam Kennedy,
@@ -458,8 +394,7 @@ chromatic,
 Curt Sampson,
 David Cantrell,
 David Golden, 
-David Wheeler,
-Elliot Shank,
+David Wheeler, 
 Janek Schleicher,
 Jim Keenan, 
 Jos I. Boumans, 
@@ -519,10 +454,9 @@ Delicious links on perl testing.
 
 =head1 LICENCE
 
-Copyright 2002-2009 Adrian Howard, All Rights Reserved.
+Copyright 2002-2007 Adrian Howard, All Rights Reserved.
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
 =cut
 
